@@ -1,4 +1,4 @@
 library(testthat)
 library(icesVocab)
 
-test_check("icesVocab")
+#test_check("icesVocab")
