@@ -8,5 +8,12 @@ test_that("findAphia doesn't crash when webservice is down", {
   expect_equal(parseVocab(res), data.frame())
 
   key <- expect_warning(findAphia("puddin"))
-  expect_equal(key, integer(0))
+
+  expect_equal(key, character(0))
+
 })
+
+# do not include this in the CRAN submission
+#test_that("R behaviour with zero row data.frames", {
+#  expect_equal(data.frame(Key = "", name = "")[integer(0), ]$Key, character(0))
+#})
